@@ -2,8 +2,7 @@ from django.db import models
 from django.db.models.signals import post_delete
 from django.dispatch import receiver
 
-
-UPLOAD_DIR_NAME = 'fs_dump'
+from . import settings as local_settings
 
 
 class Dump(models.Model):
@@ -11,8 +10,8 @@ class Dump(models.Model):
     """
 
     created_at = models.DateTimeField(verbose_name='created at', auto_now_add=True)
-    database_dump = models.FileField(verbose_name='database dump', upload_to=UPLOAD_DIR_NAME)
-    media_dump = models.FileField(verbose_name='media dump', upload_to=UPLOAD_DIR_NAME)
+    database_dump = models.FileField(verbose_name='database dump', upload_to=local_settings.UPLOAD_DIR_NAME)
+    media_dump = models.FileField(verbose_name='media dump', upload_to=local_settings.UPLOAD_DIR_NAME)
     output = models.TextField(verbose_name='output')
 
     class Meta:
